==> ViennaCL-1.7.0.tar.gz: ViennaCL-1.7.0/doc/html/search/defines_76.js <==
var searchData=
[
  ['viennacl_5fadd_5fbinary',['VIENNACL_ADD_BINARY',['../linalg_2opencl_2kernels_2matrix_8hpp.html#a67f9921aa086b1cab31a7ba49c722f84',1,'VIENNACL_ADD_BINARY():&#160;matrix.hpp'],['../linalg_2opencl_2kernels_2vector_8hpp.html#a67f9921aa086b1cab31a7ba49c722f84',1,'VIENNACL_ADD_BINARY():&#160;vector.hpp']]],
  ['viennacl_5fadd_5funary',['VIENNACL_ADD_UNARY',['../linalg_2opencl_2kernels_2matrix_8hpp.html#ae7e49843c99a526b2605212454475394',1,'VIENNACL_ADD_UNARY():&#160;matrix.hpp'],['../linalg_2opencl_2kernels_2vector_8hpp.html#ae7e49843c99a526b2605212454475394',1,'VIENNACL_ADD_UNARY():&#160;vector.hpp']]],
  ['viennacl_5famg_5fmax_5flevels',['VIENNACL_AMG_MAX_LEVELS',['../amg_8hpp.html#aec49e82ddd8b8588ba2d2048b4c063d4',1,'amg.hpp']]],
  ['viennacl_5fbisect_5fmax_5fsmall_5fmatrix',['VIENNACL_BISECT_MAX_SMALL_MATRIX',['../config_8hpp.html#aa7220f1cb89f26a7b0791610a17330b9',1,'config.hpp']]],
  ['viennacl_5fbisect_5fmax_5fthreads_5fblock',['VIENNACL_BISECT_MAX_THREADS_BLOCK',['../config_8hpp.html#a9d776da4d91c5393d73cae382fdbc48d',1,'config.hpp']]],
  ['viennacl_5fbisect_5fmax_5fthreads_5fblock_5fsmall_5fmatrix',['VIENNACL_BISECT_MAX_THREADS_BLOCK_SMALL_MATRIX',['../config_8hpp.html#a62bb16be6604cdcfdf2e6e9026876cc7',1,'config.hpp']]],
  ['viennacl_5fbisect_5fmin_5fabs_5finterval',['VIENNACL_BISECT_MIN_ABS_INTERVAL',['../config_8hpp.html#ad37f4af0725c7960b6450e315c10422e',1,'config.hpp']]],
  ['viennacl_5fbug_5freport_5fstring',['VIENNACL_BUG_REPORT_STRING',['../error_8hpp.html#a6d42757cdf0e944ebe5236aa4f96b6aa',1,'error.hpp']]],
  ['viennacl_5fcuda_5ferror_5fcheck',['VIENNACL_CUDA_ERROR_CHECK',['../cuda_8hpp.html#accdf9d18765f79ea5591e95b4b3a4d58',1,'cuda.hpp']]],
  ['viennacl_5fcuda_5flast_5ferror_5fcheck',['VIENNACL_CUDA_LAST_ERROR_CHECK',['../linalg_2cuda_2common_8hpp.html#acdb31f22f4d1e12f1c2a27d4c4aa6865',1,'common.hpp']]],
  ['viennacl_5fdevice_5fmap',['VIENNACL_DEVICE_MAP',['../device__utils_8hpp.html#a8f240cde98a71b845371268e0b2373e0',1,'device_utils.hpp']]],
  ['viennacl_5fdirect_5fsolve_5fblocksize',['VIENNACL_DIRECT_SOLVE_BLOCKSIZE',['../direct__solve_8hpp.html#a6adb698f5ba8b8fbb2e3d56e5f6caeb4',1,'direct_solve.hpp']]],
  ['viennacl_5ferr_5fcheck',['VIENNACL_ERR_CHECK',['../error_8hpp.html#a44f070f54255e72eb40c75ebd72ea602',1,'error.hpp']]],
  ['viennacl_5fexported_5ffunction',['VIENNACL_EXPORTED_FUNCTION',['../viennacl_8hpp.html#a9444346bc95708a4ecc46e63f101303d',1,'viennacl.hpp']]],
  ['viennacl_5fhandle_5fbounds',['VIENNACL_HANDLE_BOUNDS',['../matrix__product__template_8hpp.html#a68a8691a0e3237e2a504e4f016bc29a8',1,'matrix_product_template.hpp']]],
  ['viennacl_5finner_5fprod_5fimpl_5f1',['VIENNACL_INNER_PROD_IMPL_1',['../host__based_2vector__operations_8hpp.html#aaf35aadcae50e5e59946aa92b7f22aa2',1,'vector_operations.hpp']]],
  ['viennacl_5finner_5fprod_5fimpl_5f2',['VIENNACL_INNER_PROD_IMPL_2',['../host__based_2vector__operations_8hpp.html#a71fb7fd5be61a0297a8d19220cff479b',1,'vector_operations.hpp']]],
  ['viennacl_5fmajor_5fversion',['VIENNACL_MAJOR_VERSION',['../version_8hpp.html#acd20c0ad13043a1bda59bd2332c6fb3e',1,'version.hpp']]],
  ['viennacl_5fmake_5fbinary_5fop',['VIENNACL_MAKE_BINARY_OP',['../matrix__operations_8hpp.html#ac1f9f3f907a0ab4b5184bec80e657bb0',1,'matrix_operations.hpp']]],
  ['viennacl_5fmake_5funary_5felement_5fop',['VIENNACL_MAKE_UNARY_ELEMENT_OP',['../matrix__operations_8hpp.html#a79dd5e82e2b2c0561bb43316e95802ff',1,'matrix_operations.hpp']]],
  ['viennacl_5fmdot_5fworkgroup_5fnum',['VIENNACL_MDOT_WORKGROUP_NUM',['../cuda_2vector__operations_8hpp.html#af3980439d29982aff4186c79497041b3',1,'vector_operations.hpp']]],
  ['viennacl_5fmdot_5fworkgroup_5fsize',['VIENNACL_MDOT_WORKGROUP_SIZE',['../cuda_2vector__operations_8hpp.html#ac5e7443b67dcc1a373e4f1efc33bb78d',1,'vector_operations.hpp']]],
  ['viennacl_5fminor_5fversion',['VIENNACL_MINOR_VERSION',['../version_8hpp.html#a3d45b5315400d02d83c3c11f0ee6b494',1,'version.hpp']]],
  ['viennacl_5fmul_5fstride1',['VIENNACL_MUL_STRIDE1',['../matrix__product__template_8hpp.html#a2cc2037be613c430d8976673945a2200',1,'matrix_product_template.hpp']]],
  ['viennacl_5fnorm_5f1_5fimpl_5f1',['VIENNACL_NORM_1_IMPL_1',['../host__based_2vector__operations_8hpp.html#a5ac8ca975475c4350eba91cc3d97ae81',1,'vector_operations.hpp']]],
  ['viennacl_5fnorm_5f1_5fimpl_5f2',['VIENNACL_NORM_1_IMPL_2',['../host__based_2vector__operations_8hpp.html#af7aa8317885702b7e1295d9eb802fba5',1,'vector_operations.hpp']]],
  ['viennacl_5fnorm_5f2_5fimpl_5f1',['VIENNACL_NORM_2_IMPL_1',['../host__based_2vector__operations_8hpp.html#af97743e472ad389e0ad82849002fd0af',1,'vector_operations.hpp']]],
  ['viennacl_5fnorm_5f2_5fimpl_5f2',['VIENNACL_NORM_2_IMPL_2',['../host__based_2vector__operations_8hpp.html#a2fff34b2cb787d5c2ae89f59a93cfde8',1,'vector_operations.hpp']]],
  ['viennacl_5focl_5fmax_5fdevice_5fnum',['VIENNACL_OCL_MAX_DEVICE_NUM',['../device__utils_8hpp.html#a2d90eef0a67b2af2801368b3ab5b357f',1,'VIENNACL_OCL_MAX_DEVICE_NUM():&#160;device_utils.hpp'],['../ocl_2forwards_8h.html#a2d90eef0a67b2af2801368b3ab5b357f',1,'VIENNACL_OCL_MAX_DEVICE_NUM():&#160;forwards.h']]],
  ['viennacl_5fopenmp_5filu_5fmin_5fsize',['VIENNACL_OPENMP_ILU_MIN_SIZE',['../host__based_2ilu__operations_8hpp.html#a780bce38f8ac0813b5e8978102d28206',1,'ilu_operations.hpp']]],
  ['viennacl_5fopenmp_5fvector_5fmin_5fsize',['VIENNACL_OPENMP_VECTOR_MIN_SIZE',['../host__based_2iterative__operations_8hpp.html#aa1b0719a06924fc82f8d8ed6c739a04d',1,'VIENNACL_OPENMP_VECTOR_MIN_SIZE():&#160;iterative_operations.hpp'],['../host__based_2vector__operations_8hpp.html#aa1b0719a06924fc82f8d8ed6c739a04d',1,'VIENNACL_OPENMP_VECTOR_MIN_SIZE():&#160;vector_operations.hpp']]],
  ['viennacl_5fpatch_5fversion',['VIENNACL_PATCH_VERSION',['../version_8hpp.html#ac4f352886df7f3da2e958797a8629b87',1,'version.hpp']]],
  ['viennacl_5fscheduler_5fgenerate_5funary_5felement_5fop',['VIENNACL_SCHEDULER_GENERATE_UNARY_ELEMENT_OP',['../execute__elementwise_8hpp.html#a580ada22945ca328dddeca2b1ace85d0',1,'VIENNACL_SCHEDULER_GENERATE_UNARY_ELEMENT_OP():&#160;execute_elementwise.hpp'],['../execute__elementwise_8hpp.html#a580ada22945ca328dddeca2b1ace85d0',1,'VIENNACL_SCHEDULER_GENERATE_UNARY_ELEMENT_OP():&#160;execute_elementwise.hpp']]],
  ['viennacl_5fspai_5fk_5fb',['VIENNACL_SPAI_K_b',['../detail_2spai_2spai_8hpp.html#a1dda26d5d7af5cbba03485b2da3075b2',1,'spai.hpp']]],
  ['viennacl_5ftranslate_5felement_5fto_5fstring',['VIENNACL_TRANSLATE_ELEMENT_TO_STRING',['../io_8hpp.html#a999a1a2fb7551922b31981bca75d8f46',1,'io.hpp']]],
  ['viennacl_5ftranslate_5fop_5fto_5fstring',['VIENNACL_TRANSLATE_OP_TO_STRING',['../io_8hpp.html#a286712d1ee320d6491aa87dda9d578e5',1,'io.hpp']]],
  ['viennacl_5fvstore',['VIENNACL_VSTORE',['../matrix__product__template_8hpp.html#a3eee04070ac5528e391f0f7ed0c423c2',1,'matrix_product_template.hpp']]],
  ['viennacl_5fwith_5fopencl',['VIENNACL_WITH_OPENCL',['../opencl_8cpp.html#a017c0eee41b5f529d1e9a9492c171fe2',1,'opencl.cpp']]],
  ['viennacl_5fwith_5fublas',['VIENNACL_WITH_UBLAS',['../blas3__solve_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;blas3_solve.cpp'],['../external__1_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;external_1.cpp'],['../external__2_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;external_2.cpp'],['../matrix__float__double_8hpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;matrix_float_double.hpp'],['../matrix__int_8hpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;matrix_int.hpp'],['../matrix__vector_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;matrix_vector.cpp'],['../matrix__vector__int_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;matrix_vector_int.cpp'],['../qr__method__func_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;qr_method_func.cpp'],['../tests_2src_2scheduler__matrix_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;scheduler_matrix.cpp'],['../scheduler__matrix__matrix_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;scheduler_matrix_matrix.cpp'],['../scheduler__matrix__vector_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;scheduler_matrix_vector.cpp'],['../scheduler__sparse_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;scheduler_sparse.cpp'],['../scheduler__vector_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;scheduler_vector.cpp'],['../tests_2src_2sparse_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;sparse.cpp'],['../spmdm_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;spmdm.cpp'],['../tql_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;tql.cpp'],['../vector__int_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;vector_int.cpp'],['../vector__multi__inner__prod_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;vector_multi_inner_prod.cpp'],['../vector__uint_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;vector_uint.cpp'],['../blas3range_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;blas3range.cpp'],['../benchmarks_2qr_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;qr.cpp'],['../solver_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;solver.cpp'],['../examples_2benchmarks_2sparse_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;sparse.cpp']]]
];

==> ViennaCL-1.7.1.tar.gz: ViennaCL-1.7.1/doc/html/search/defines_76.js <==
var searchData=
[
  ['viennacl_5famg_5fmax_5flevels',['VIENNACL_AMG_MAX_LEVELS',['../amg_8hpp.html#aec49e82ddd8b8588ba2d2048b4c063d4',1,'amg.hpp']]],
  ['viennacl_5fbisect_5fmax_5fsmall_5fmatrix',['VIENNACL_BISECT_MAX_SMALL_MATRIX',['../config_8hpp.html#aa7220f1cb89f26a7b0791610a17330b9',1,'config.hpp']]],
  ['viennacl_5fbisect_5fmax_5fthreads_5fblock',['VIENNACL_BISECT_MAX_THREADS_BLOCK',['../config_8hpp.html#a9d776da4d91c5393d73cae382fdbc48d',1,'config.hpp']]],
  ['viennacl_5fbisect_5fmax_5fthreads_5fblock_5fsmall_5fmatrix',['VIENNACL_BISECT_MAX_THREADS_BLOCK_SMALL_MATRIX',['../config_8hpp.html#a62bb16be6604cdcfdf2e6e9026876cc7',1,'config.hpp']]],
  ['viennacl_5fbisect_5fmin_5fabs_5finterval',['VIENNACL_BISECT_MIN_ABS_INTERVAL',['../config_8hpp.html#ad37f4af0725c7960b6450e315c10422e',1,'config.hpp']]],
  ['viennacl_5fbug_5freport_5fstring',['VIENNACL_BUG_REPORT_STRING',['../error_8hpp.html#a6d42757cdf0e944ebe5236aa4f96b6aa',1,'error.hpp']]],
  ['viennacl_5fcuda_5ferror_5fcheck',['VIENNACL_CUDA_ERROR_CHECK',['../cuda_8hpp.html#accdf9d18765f79ea5591e95b4b3a4d58',1,'cuda.hpp']]],
  ['viennacl_5fcuda_5flast_5ferror_5fcheck',['VIENNACL_CUDA_LAST_ERROR_CHECK',['../linalg_2cuda_2common_8hpp.html#acdb31f22f4d1e12f1c2a27d4c4aa6865',1,'common.hpp']]],
  ['viennacl_5fdevice_5fmap',['VIENNACL_DEVICE_MAP',['../device__utils_8hpp.html#a8f240cde98a71b845371268e0b2373e0',1,'device_utils.hpp']]],
  ['viennacl_5fdirect_5fsolve_5fblocksize',['VIENNACL_DIRECT_SOLVE_BLOCKSIZE',['../direct__solve_8hpp.html#a6adb698f5ba8b8fbb2e3d56e5f6caeb4',1,'direct_solve.hpp']]],
  ['viennacl_5ferr_5fcheck',['VIENNACL_ERR_CHECK',['../error_8hpp.html#a44f070f54255e72eb40c75ebd72ea602',1,'error.hpp']]],
  ['viennacl_5fexported_5ffunction',['VIENNACL_EXPORTED_FUNCTION',['../viennacl_8hpp.html#a9444346bc95708a4ecc46e63f101303d',1,'viennacl.hpp']]],
  ['viennacl_5fhandle_5fbounds',['VIENNACL_HANDLE_BOUNDS',['../matrix__product__template_8hpp.html#a68a8691a0e3237e2a504e4f016bc29a8',1,'matrix_product_template.hpp']]],
  ['viennacl_5finner_5fprod_5fimpl_5f1',['VIENNACL_INNER_PROD_IMPL_1',['../host__based_2vector__operations_8hpp.html#aaf35aadcae50e5e59946aa92b7f22aa2',1,'vector_operations.hpp']]],
  ['viennacl_5finner_5fprod_5fimpl_5f2',['VIENNACL_INNER_PROD_IMPL_2',['../host__based_2vector__operations_8hpp.html#a71fb7fd5be61a0297a8d19220cff479b',1,'vector_operations.hpp']]],
  ['viennacl_5fmajor_5fversion',['VIENNACL_MAJOR_VERSION',['../version_8hpp.html#acd20c0ad13043a1bda59bd2332c6fb3e',1,'version.hpp']]],
  ['viennacl_5fmake_5fbinary_5fop',['VIENNACL_MAKE_BINARY_OP',['../matrix__operations_8hpp.html#ac1f9f3f907a0ab4b5184bec80e657bb0',1,'matrix_operations.hpp']]],
  ['viennacl_5fmake_5funary_5felement_5fop',['VIENNACL_MAKE_UNARY_ELEMENT_OP',['../matrix__operations_8hpp.html#a79dd5e82e2b2c0561bb43316e95802ff',1,'matrix_operations.hpp']]],
  ['viennacl_5fmdot_5fworkgroup_5fnum',['VIENNACL_MDOT_WORKGROUP_NUM',['../cuda_2vector__operations_8hpp.html#af3980439d29982aff4186c79497041b3',1,'vector_operations.hpp']]],
  ['viennacl_5fmdot_5fworkgroup_5fsize',['VIENNACL_MDOT_WORKGROUP_SIZE',['../cuda_2vector__operations_8hpp.html#ac5e7443b67dcc1a373e4f1efc33bb78d',1,'vector_operations.hpp']]],
  ['viennacl_5fminor_5fversion',['VIENNACL_MINOR_VERSION',['../version_8hpp.html#a3d45b5315400d02d83c3c11f0ee6b494',1,'version.hpp']]],
  ['viennacl_5fmul_5fstride1',['VIENNACL_MUL_STRIDE1',['../matrix__product__template_8hpp.html#a2cc2037be613c430d8976673945a2200',1,'matrix_product_template.hpp']]],
  ['viennacl_5fnorm_5f1_5fimpl_5f1',['VIENNACL_NORM_1_IMPL_1',['../host__based_2vector__operations_8hpp.html#a5ac8ca975475c4350eba91cc3d97ae81',1,'vector_operations.hpp']]],
  ['viennacl_5fnorm_5f1_5fimpl_5f2',['VIENNACL_NORM_1_IMPL_2',['../host__based_2vector__operations_8hpp.html#af7aa8317885702b7e1295d9eb802fba5',1,'vector_operations.hpp']]],
  ['viennacl_5fnorm_5f2_5fimpl_5f1',['VIENNACL_NORM_2_IMPL_1',['../host__based_2vector__operations_8hpp.html#af97743e472ad389e0ad82849002fd0af',1,'vector_operations.hpp']]],
  ['viennacl_5fnorm_5f2_5fimpl_5f2',['VIENNACL_NORM_2_IMPL_2',['../host__based_2vector__operations_8hpp.html#a2fff34b2cb787d5c2ae89f59a93cfde8',1,'vector_operations.hpp']]],
  ['viennacl_5focl_5fmax_5fdevice_5fnum',['VIENNACL_OCL_MAX_DEVICE_NUM',['../device__utils_8hpp.html#a2d90eef0a67b2af2801368b3ab5b357f',1,'VIENNACL_OCL_MAX_DEVICE_NUM():&#160;device_utils.hpp'],['../ocl_2forwards_8h.html#a2d90eef0a67b2af2801368b3ab5b357f',1,'VIENNACL_OCL_MAX_DEVICE_NUM():&#160;forwards.h']]],
  ['viennacl_5fopenmp_5filu_5fmin_5fsize',['VIENNACL_OPENMP_ILU_MIN_SIZE',['../host__based_2ilu__operations_8hpp.html#a780bce38f8ac0813b5e8978102d28206',1,'ilu_operations.hpp']]],
  ['viennacl_5fopenmp_5fmatrix_5fmin_5fsize',['VIENNACL_OPENMP_MATRIX_MIN_SIZE',['../host__based_2matrix__operations_8hpp.html#a4b50534a3fce434335f67357a8d39f30',1,'matrix_operations.hpp']]],
  ['viennacl_5fopenmp_5fvector_5fmin_5fsize',['VIENNACL_OPENMP_VECTOR_MIN_SIZE',['../host__based_2iterative__operations_8hpp.html#aa1b0719a06924fc82f8d8ed6c739a04d',1,'VIENNACL_OPENMP_VECTOR_MIN_SIZE():&#160;iterative_operations.hpp'],['../host__based_2vector__operations_8hpp.html#aa1b0719a06924fc82f8d8ed6c739a04d',1,'VIENNACL_OPENMP_VECTOR_MIN_SIZE():&#160;vector_operations.hpp']]],
  ['viennacl_5fpatch_5fversion',['VIENNACL_PATCH_VERSION',['../version_8hpp.html#ac4f352886df7f3da2e958797a8629b87',1,'version.hpp']]],
  ['viennacl_5fscheduler_5fgenerate_5funary_5felement_5fop',['VIENNACL_SCHEDULER_GENERATE_UNARY_ELEMENT_OP',['../execute__elementwise_8hpp.html#a580ada22945ca328dddeca2b1ace85d0',1,'VIENNACL_SCHEDULER_GENERATE_UNARY_ELEMENT_OP():&#160;execute_elementwise.hpp'],['../execute__elementwise_8hpp.html#a580ada22945ca328dddeca2b1ace85d0',1,'VIENNACL_SCHEDULER_GENERATE_UNARY_ELEMENT_OP():&#160;execute_elementwise.hpp']]],
  ['viennacl_5fspai_5fk_5fb',['VIENNACL_SPAI_K_b',['../detail_2spai_2spai_8hpp.html#a1dda26d5d7af5cbba03485b2da3075b2',1,'spai.hpp']]],
  ['viennacl_5ftranslate_5felement_5fto_5fstring',['VIENNACL_TRANSLATE_ELEMENT_TO_STRING',['../io_8hpp.html#a999a1a2fb7551922b31981bca75d8f46',1,'io.hpp']]],
  ['viennacl_5ftranslate_5fop_5fto_5fstring',['VIENNACL_TRANSLATE_OP_TO_STRING',['../io_8hpp.html#a286712d1ee320d6491aa87dda9d578e5',1,'io.hpp']]],
  ['viennacl_5fvstore',['VIENNACL_VSTORE',['../matrix__product__template_8hpp.html#a3eee04070ac5528e391f0f7ed0c423c2',1,'matrix_product_template.hpp']]],
  ['viennacl_5fwith_5fopencl',['VIENNACL_WITH_OPENCL',['../opencl_8cpp.html#a017c0eee41b5f529d1e9a9492c171fe2',1,'opencl.cpp']]],
  ['viennacl_5fwith_5fublas',['VIENNACL_WITH_UBLAS',['../external__1_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;external_1.cpp'],['../external__2_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;external_2.cpp'],['../qr__method__func_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;qr_method_func.cpp'],['../scheduler__matrix_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;scheduler_matrix.cpp'],['../blas3range_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;blas3range.cpp'],['../benchmarks_2qr_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;qr.cpp'],['../solver_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;solver.cpp'],['../examples_2benchmarks_2sparse_8cpp.html#af9d2311f8dd8c5536101e46f1351df56',1,'VIENNACL_WITH_UBLAS():&#160;sparse.cpp']]]
];
